Circle

Struct Circle 

pub struct Circle<Coord: Coordinate2D + Coordinate> {
    pub center: Coord,
    pub radius: f64,
}
Represents a circle in 2 dimensions

Fields

center: Coord

The center of this circle

radius: f64

The radius of this circle

Implementations

Source

impl<Coord: Coordinate2D + Coordinate> Circle<Coord>

pub fn new(center: Coord, radius: f64) -> Circle<Coord>

Creates a new circle with a center and a radius

pub fn arc( &self, start_radians: f64, end_radians: f64, ) -> CircularArc<'_, Coord>

Returns an object representing an arc from this circle

pub fn to_curves<Curve: BezierCurveFactory<Point = Coord>>(&self) -> Vec<Curve>

Returns a set of bezier curves that approximate this circle

pub fn to_path<P: BezierPathFactory<Point = Coord>>(&self) -> P

Returns a path that approximates this circle