pub struct Circle<Coord: Coordinate2D + Coordinate> {
pub center: Coord,
pub radius: f64,
}Expand description
Represents a circle in 2 dimensions
Fields
center: CoordThe center of this circle
radius: f64The radius of this circle
Implementations
Sourceimpl<Coord: Coordinate2D + Coordinate> Circle<Coord>
impl<Coord: Coordinate2D + Coordinate> Circle<Coord>
Sourcepub fn new(center: Coord, radius: f64) -> Circle<Coord>
pub fn new(center: Coord, radius: f64) -> Circle<Coord>
Creates a new circle with a center and a radius
Sourcepub fn arc(
&self,
start_radians: f64,
end_radians: f64,
) -> CircularArc<'_, Coord>
pub fn arc( &self, start_radians: f64, end_radians: f64, ) -> CircularArc<'_, Coord>
Returns an object representing an arc from this circle
Sourcepub fn to_curves<Curve: BezierCurveFactory<Point = Coord>>(&self) -> Vec<Curve>
pub fn to_curves<Curve: BezierCurveFactory<Point = Coord>>(&self) -> Vec<Curve>
Returns a set of bezier curves that approximate this circle
Sourcepub fn to_path<P: BezierPathFactory<Point = Coord>>(&self) -> P
pub fn to_path<P: BezierPathFactory<Point = Coord>>(&self) -> P
Returns a path that approximates this circle